@@ -2,9 +2,6 @@ package Imager::Expr;
 
 use Imager::Regops;
 use strict;
-use vars qw($VERSION);
-
-$VERSION = "1.003";
 
 my %expr_types;
 
@@ -29,7 +26,7 @@ my %default_constants =
 
 sub new {
   my ($class, $opts) = @_;
-
+  
   # possibly this is a very bad idea
   my ($type) = grep exists $expr_types{$_}, keys %$opts;
   die "Imager::Expr: No known expression type"
@@ -69,22 +66,15 @@ sub cregs {
 
 my $numre = '[+-]?(?:\d+\.?\d*|\.\d+)(?:[eE][+-]?\d+)?';
 
-sub numre {
-  $numre;
-}
-
 # optimize the code
 sub optimize {
   my ($self) = @_;
 
   my @ops = @{$self->{ops}};
 
-  # this function cannot current handle code with jumps
-  return 1 if grep $_->[0] =~ /^jump/, @ops;
-
   # optimization - common sub-expression elimination
   # it's possible to fold this into the code generation - but it will wait
-
+  
   my $max_opr = $Imager::Regops::MaxOperands;
   my $attr = \%Imager::Regops::Attr;
   my $foundops = 1;
@@ -135,7 +125,7 @@ sub assemble {
   my @ops = @{$self->{ops}};
   for my $op (@ops) {
     $op->[0] = $attr->{$op->[0]}{opcode};
-    for (@{$op}[1..$max_opr+1]) { s/^[rpj]// }
+		for (@{$op}[1..$max_opr+1]) { s/^[rp]// }
   }
   my $pack = $Imager::Regops::PackCode x (2+$Imager::Regops::MaxOperands);
 
@@ -256,12 +246,11 @@ sub dumpcode {
   my %names = map { $attr->{$_}{opcode}, $_ } keys %Imager::Regops::Attr;
   my @vars = $self->_variables();
   my $result = '';
-  my $index = 0;
   while (my @op = splice(@code, 0, 2+$Imager::Regops::MaxOperands)) {
     my $opcode = shift @op;
     my $name = $names{$opcode};
     if ($name) {
-      $result .= "j$index: $name($opcode)";
+      $result .= "$name($opcode)";
       my @types = split //, $attr->{$name}{types};
       for my $parm (@types) {
 	my $reg = shift @op;
@@ -275,7 +264,7 @@ sub dumpcode {
 	  }
 	}
       }
-
+      
       $result .= " -> $attr->{$name}{result}$op[-1]"
 	if $attr->{$name}{result};
       $result .= "\n";
@@ -283,7 +272,6 @@ sub dumpcode {
     else {
       $result .= "unknown($opcode) @op\n";
     }
-    ++$index;
   }
 
   $result;
@@ -300,10 +288,9 @@ my %op_names = ( '+'=>'add', '-'=>'subtract', '*'=>'mult', '/' => 'div',
 
 sub compile {
   my ($self, $expr, $opts) = @_;
-
-  $expr =~ s/#.*//; # remove comments
+  
   my @st_ops = split ' ', $expr;
-
+  
   for (@st_ops) {
     $_ = $op_names{$_} if exists $op_names{$_};
     $_ = $self->{constants}{$_} if exists $self->{constants}{$_};
@@ -394,7 +381,7 @@ funccall : identifier '(' exprlist ')'
 { $return = [ $item[1], @{$item[3]} ] }
 
 identifier : /[^\W\d]\w*/ { $return = $item[1] }
-
+       
 GRAMMAR
 
 my $parser;
@@ -452,7 +439,7 @@ sub compile {
 
 sub gencode {
   my ($self, $tree) = @_;
-
+  
   if (ref $tree) {
     my ($op, @parms) = @$tree;
 
@@ -464,7 +451,7 @@ sub gencode {
       $subtree = $self->gencode($subtree);
     }
     my $types = join("", map {substr($_,0,1)} @parms);
-
+    
     if (length($types) < length($Attr{$op}{types})) {
       die "Too few parameters in call to $op";
     }
@@ -538,11 +525,9 @@ To create a new Imager::Expr object, call:
 You will need to set an expression value and you may set any of the
 following:
 
-=over
+=over 4
 
-=item *
-
-constants
+=item constants
 
 A hashref defining extra constants for expression parsing.  The names
 of the constants must be valid identifiers (/[^\W\d]\w*/) and the
@@ -551,9 +536,7 @@ scalars).
 
 Imager::Expr may define it's own constants (currently just pi.)
 
-=item *
-
-variables
+=item variables
 
 A reference to an array of variable names.  These are allocated
 numeric registers starting from register zero.
@@ -604,28 +587,7 @@ I'll write this one day.
 
 Methods used by parsers:
 
-=over
-
-=item compile
-
-This is the main method you'll need to implement in a parser.  See the
-existing parsers for a guide.
-
-It's supplied the following parameters:
-
-=over
-
-=item *
-
-$expr - the expression to be parsed
-
-=item *
-
-$options - the options hash supplied to transform2.
-
-=back
-
-Return an array ref of array refs containing opcodes and operands.
+=over 4
 
 =item @vars = $self->_variables()
 
@@ -641,29 +603,6 @@ Set the return value of Imager::Expr::error()
 
 Converts marginally parsed RPN to register code.
 
-=item assemble
-
-Called to convert op codes into byte code.
-
-=item numre
-
-Returns a regular expression that matches floating point numbers.
-
-=item optimize
-
-Optimizes the assembly code, including attempting common subexpression
-elimination and strength reducing division by a constant into
-multiplication by a constant.
-
-=item register_type
-
-Called by a new expression parser implementation to register itself,
-call as:
-
-  YourClassName->register_type('type code');
-
-where type code is the parameter that will accept the expression.
-
 =back
 
 =head2 Future compatibility
